import { FC, PropsWithChildren, useCallback, useMemo } from "react";

import { Global, css } from '@emotion/react'
import { ThemeProvider, Theme } from '@mui/material/styles';
import createCache from '@emotion/cache';
import { CacheProvider } from '@emotion/react';

import { generateGlobalColorCss } from "../utils";

import styles from "../styles/global.css";

type NuskinThemeProviderProps = {
  isSSR?: boolean;
  cacheKey?: string;
  appTheme?: Theme;
};

const getCacheKey = (key: string) => {
  return createCache({ key });
};

const NuskinThemeProvider: FC<PropsWithChildren<NuskinThemeProviderProps>> = (props) => {
  const { isSSR = false, children, cacheKey = 'nuskin-default', appTheme } = props;
  const cache = useMemo(() => getCacheKey(cacheKey), [cacheKey]);

  const renderThemeProvider = useCallback(() => (
      <ThemeProvider theme={appTheme || {}}>
          <Global
              styles={css`
                  ${styles}
                  ${generateGlobalColorCss(appTheme)}
              `}
          />
          {children}
      </ThemeProvider>
  ), [appTheme]);

  if (isSSR) {
      return (
          <CacheProvider value={cache}>
              { renderThemeProvider() }
          </CacheProvider>
      )
  }
  return renderThemeProvider();
};

export default NuskinThemeProvider;
