import { useMemo } from 'react';

import useMediaQuery from '@mui/material/useMediaQuery';
import Button from '@mui/material/Button';

import { NuskinThemeProvider } from "../components";
import { NextPageContext } from "next";
import { nuskinThemeTitleStyle } from "./theme-builder";
import { createNuskinTheme } from "../utils";
import { ColorKeys, Colors } from "../themes/types";

type HomePageProps = {
  palette: Colors;
  theme: string;
};

const buttonStyle = {
  marginBottom: '10px',
  marginLeft: 150,
};

export default function Home({ palette, theme }: HomePageProps) {
  const prefersDarkMode = useMediaQuery('(prefers-color-scheme: dark)');
  const appTheme = useMemo(() => {
    return createNuskinTheme(palette, prefersDarkMode);
  }, [prefersDarkMode, palette]);
  const colorVariables = Object.keys(palette) as ColorKeys[];

  return (
    <NuskinThemeProvider cacheKey="nuskin-foundation-ui" appTheme={appTheme} isSSR>
      <h2 style={nuskinThemeTitleStyle}>
        {theme === 'force-for-good' ? 'Force-For-Good-Button-Theme' : 'Nuskin-Button-Theme'}
      </h2>
      {colorVariables?.map((color) => (
        <div style={buttonStyle} key={color}>
          <Button variant="contained" color={color}>
            {' '}
            nuskin button{' '}
          </Button>
        </div>
      ))}
      <h1 className="bg-accentColorA text-white">
        Configuring Tailwind
      </h1>
    </NuskinThemeProvider>
  );
}

Home.getInitialProps = async (ctx: NextPageContext) => {
  const { query, req } = ctx || {};
  const theme = query?.theme || 'nuskin-theme';
  let response;
  try {
    /*
     * [Todo] - Determine the environment in which the theme has to fetch the json
     */
    let config = await fetch(`http://${req?.headers.host}/${theme}.json`);
    response = await config.json();
  } catch {
    console.log('Theme Not found');
  }
  return {
    palette: response,
    theme: theme,
  };
};
