import { Theme, createTheme } from "@mui/material";

import { palette as defaultPalette } from "../themes/genome-foundation/";
export * from "./button-utils";
import { ColorKeys, Colors, CommonColors } from "../themes/types";

type CommonColorsName = keyof CommonColors;

export const generatePalette = (colors: Colors, prefersDarkMode = false) => {
    const colorKeys = Object.keys(colors) as ColorKeys[];
    const paletteColors = colorKeys.reduce((result, paletteName) => {
        if (prefersDarkMode) {
            const colorObject = colors[paletteName];
            const darkMode = colorObject?.darkMode;
            if (darkMode) {
                result[paletteName] = darkMode;
            }
        }
        return result;
    }, {} as Colors);
    return paletteColors;
};

export const createNuskinTheme = (palette: Colors = defaultPalette, prefersDarkMode?: boolean) => {
    const muiTheme = createTheme({ palette })
    return {
        ...muiTheme,
        palette: {
            ...muiTheme.palette,
            ...generatePalette(palette, prefersDarkMode),
        }
    };
};

export const generateGlobalColorCss = (appTheme?: Theme) => {
    if (!appTheme) {
        return "";
    }
    
    let colorCssString = "";
    const palette = appTheme?.palette;

    const allColorNames = Object.keys(palette) as ColorKeys[];
    const commonColorNames = Object.keys(palette.common) as CommonColorsName[];
    
    const colors = allColorNames?.filter((color: ColorKeys) => {
        const colorInPalette = palette?.[color];
        return colorInPalette?.main;
    });

    const generateColors = (name: string, value: string) => {
        return `
            .bg-${name} {
                background: ${value}
            }
            .text-${name} {
                color: ${value};
            }
            .border-${name} {
                border-color: ${value};
            }
        `;
    };

    colorCssString = colors.reduce((result, colorName) => {
        const colorValue = palette[colorName]?.main;
        result += generateColors(colorName, colorValue);
        return result;
    }, "");

    colorCssString = commonColorNames.reduce((result, colorName: CommonColorsName) => {
        const commonColor = palette?.common;
        const colorValue = commonColor[colorName]
        result += generateColors(colorName, colorValue);
        return result;
    }, colorCssString);

    return colorCssString;
};
